@@ -44,12 +44,14 @@ class ToolbarEnd(Gtk.Bin):
             "shuffle",
             GLib.VariantType.new("s"),
             GLib.Variant("s", "none"))
+        self.__shuffle_action.set_state(App().settings.get_value("shuffle"))
         self.__shuffle_action.connect("change-state",
                                       self.__on_shuffle_change_state)
         self.__playback_action = Gio.SimpleAction.new_stateful(
             "playback",
             GLib.VariantType.new("s"),
             GLib.Variant("s", "none"))
+        self.__playback_action.set_state(App().settings.get_value("playback"))
         self.__playback_action.connect("change-state",
                                        self.__on_playback_change_state)
         App().add_action(self.__shuffle_action)
@@ -183,11 +185,29 @@ class ToolbarEnd(Gtk.Bin):
            Create submenu
            @param button as Gtk.MenuButton
         """
-        # Create submenu "Configure party mode"
-        self.__party_submenu.remove_all()
-        self.__init_party_submenu()
-        self.__next_popover.inhibit(True)
-        button.connect("toggled", self.__on_popover_closed)
+        if button.get_active():
+            # Create submenu "Configure party mode"
+            self.__party_submenu.remove_all()
+            self.__init_party_submenu()
+            self.__next_popover.hide()
+            self.__next_popover.inhibit(True)
+        else:
+            self.__next_popover.inhibit(False)
+            if self.__next_popover.should_be_shown():
+                self.__next_popover.show()
+
+    def _on_settings_button_toggled(self, button):
+        """
+           Create submenu
+           @param button as Gtk.MenuButton
+        """
+        if button.get_active():
+            self.__next_popover.hide()
+            self.__next_popover.inhibit(True)
+        else:
+            self.__next_popover.inhibit(False)
+            if self.__next_popover.should_be_shown():
+                self.__next_popover.show()
 
 #######################
 # PRIVATE             #
