@@ -45,10 +45,12 @@ class LyricsView(View, InfoController):
         self.add(builder.get_object("widget"))
         self.connect("size-allocate", self.__on_size_allocate)
 
-    def populate(self):
+    def populate(self, track):
         """
             Set lyrics
+            @param track as Track
         """
+        self.__current_track = track
         self.update_artwork(self.__current_width,
                             self.__current_height,
                             True)
@@ -62,7 +64,7 @@ class LyricsView(View, InfoController):
         lyrics = None
         reader = TagReader()
         try:
-            info = reader.get_info(App().player.current_track.uri)
+            info = reader.get_info(self.__current_track.uri)
         except:
             info = None
         if info is not None:
@@ -84,7 +86,7 @@ class LyricsView(View, InfoController):
             Update lyrics
             @param player as Player
         """
-        self.populate()
+        self.populate(App().player.current_track)
 
 ############
 # PRIVATE  #
@@ -96,8 +98,8 @@ class LyricsView(View, InfoController):
         self.__downloads_running += 1
         # Update lyrics
         task_helper = TaskHelper()
-        if App().player.current_track.id == Type.RADIOS:
-            split = App().player.current_track.name.split(" - ")
+        if self.__current_track.id == Type.RADIOS:
+            split = self.__current_track.name.split(" - ")
             if len(split) < 2:
                 return
             artist = GLib.uri_escape_string(
@@ -110,11 +112,11 @@ class LyricsView(View, InfoController):
                 False)
         else:
             artist = GLib.uri_escape_string(
-                App().player.current_track.name,
+                self.__current_track.name,
                 None,
                 False)
             title = GLib.uri_escape_string(
-                App().player.current_track.name,
+                self.__current_track.name,
                 None,
                 False)
         uri = "http://lyrics.wikia.com/wiki/%s:%s" % (artist, title)
@@ -132,15 +134,15 @@ class LyricsView(View, InfoController):
         self.__downloads_running += 1
         # Update lyrics
         task_helper = TaskHelper()
-        if App().player.current_track.id == Type.RADIOS:
+        if self.__current_track.id == Type.RADIOS:
             split = App().player.current_track.name.split(" - ")
             if len(split) < 2:
                 return
             artist = split[0]
             title = split[1]
         else:
-            artist = App().player.current_track.artists[0]
-            title = App().player.current_track.name
+            artist = self.__current_track.artists[0]
+            title = self.__current_track.name
         string = escape("%s %s" % (artist, title))
         uri = "https://genius.com/%s-lyrics" % string.replace(" ", "-")
         task_helper.load_uri_content(
